<?php
/*
Plugin Name: Digg This Button
Plugin URI: http://netweblogic.com/wordpress/digg-this-button/
Description: Adds the smarter digg button. Extended options like topics, prefilled descriptions, shortcodes etc. allow full control of your digg icons.
Author: NetWebLogic LLC
Version: 2.0
Author URI: http://netweblogic.com
*/
/*
Copyright (C) 2008 NetWebLogic LLC

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

class DiggThisButton {

	var $topicArray = array('arts_culture', 'autos', 'baseball', 'basketball', 'business_finance', 'celebrity', 'comedy', 'comics_animation', 'design', 'educational', 'environment', 'extreme_sports', 'food_drink', 'football', 'gadgets', 'gaming_news', 'general_sciences', 'golf', 'hardware', 'health', 'hockey', 'linux_unix', 'microsoft', 'mods', 'motorsport', 'movies', 'music', 'nintendo', 'odd_stuff', 'olympics', 'other_sports', 'pc_games', 'people', 'pets_animals', 'playable_web_games', 'playstation', 'political_opinion', 'politics', 'programming', 'security', 'soccer', 'software', 'space', 'tech_news', 'television', 'tennis', 'travel_places', 'world_news', 'xbox');
	var $skinArray = array('default' => 'DiggMedium', 'medium' => 'DiggMedium', 'compact' => 'DiggCompact', 'icon'=>'DiggIcon', 'large' => 'DiggLarge');
	var $mediaArray = array('video', 'image', 'news');
	var $posH = array('right', 'left', 'none');
	var $posV = array('top', 'bottom');
	var $shortcode = false;
	var $diggthis_data;
	
	// Class initialization
	function DiggThisButton() {
		//Make decision on what to display
		$this->diggthis_data = get_option('diggthis_data');
		wp_enqueue_script('diggthis', 'http://widgets.digg.com/buttons.js');
		add_action('wp_head', array(&$this, 'head'));
		add_filter('the_content', array(&$this, 'content'), 1000, 1);
		add_filter('the_excerpt', array(&$this, 'content'), 1000, 1);
		add_shortcode('diggthis', array(&$this, 'shortcode'));	
	}
	
	function head(){
		if( trim($this->diggthis_data['css']) != '' ){
			$style = $this->diggthis_data['css'];
			//clean any html tags out of this to avoid xss attacks
			$style = preg_replace("/<.+>/", '', $style);
			echo "<style type='text/css'>";
			echo $style;
			echo "</style>";
		}	
	}
	
	function content($content){
		if($this->inProgress != true){
			global $post;
			$diggthis_post = unserialize(get_post_meta($post->ID, '_diggthis_data',true));
			$diggthis_post = (is_array($diggthis_post)) ? $diggthis_post : array();
			$this->inProgress = true; //to stop from adding it to the excerpt if doing this here.
			//Check whether we are to show this
			$display = false;
			//Pages
			$display = ($this->diggthis_data['display_pages']=='1' && is_page()) ? true:$display;
			$display = ($this->diggthis_data['display_posts']=='1' && is_single()) ? true:$display;
			$display = ( (is_single() or is_page()) and $diggthis_post['show'] == 'yes' ) ? true:$display;
			//Lists
			$display = ($this->diggthis_data['display_lists']=='1' && !is_singular()) ? true:$display;
			//Searches
			$display = ($this->diggthis_data['display_search']!='1' && $_POST['s']!='' ) ? false:$display;
			if($display){
				ob_start();
				$this->display( $diggthis_post );
			}
			$button = ob_get_clean();
			if($this->diggthis_data['pos_v'] == 'bottom'){
				$content = $content . $button;
			}else{
				$content = $button . $content;
			}
			$this->inProgress = false;
			return $content;
		}
		return $content;
	}
	
	function shortcode( $atts = array() ){
		ob_start();
		global $post;
		$this->shortcode = true;
		$atts = (is_array($atts)) ? $atts : array();
		unset($this->diggthis_data['pos_h']);
		unset($this->diggthis_data['pos_v']);
		$this->display( $atts );
		$this->diggthis_data = get_option('diggthis_data');
		$this->shortcode = false;
		return ob_get_clean();
	}
	
	function display( $atts = array() ){
		//If post has overriding show option, obey it
		//Continue with showing
		$diggthis_data = array_merge( $this->diggthis_data, $atts);
		if( $diggthis_data['show'] == 'no' ){ return; }
		$style = '';
		if( $diggthis_data['style'] == '' && $this->shortcode != true ){
			switch ( $diggthis_data['pos_h']) {
				case 'left' :
					$style .= 'float:left;';
					if($diggthis_data['pos_v'] == 'bottom'){
						$style .= 'margin:0px 10px 10px 0px;';
					}elseif ($diggthis_data['pos_v'] == 'top'){
						$style .= 'margin:10px 10px 0px 0px;';
					}
					break;
				default :
					$style .= 'float:right;';
					if($diggthis_data['pos_v'] == 'bottom'){
						$style .= 'margin:10px 10px 0px 0px;';
					}elseif ($diggthis_data['pos_v'] == 'top'){
						$style .= 'margin:0px 0px 10px 10px;';
					}
					break;
			}
		}else{
			$style = $diggthis_data['style']; 
		}
		
		//Figure out which skin to use - partially for plugin backward compatability
		if( array_key_exists($diggthis_data['skin'], $this->skinArray) ){
			$diggSkin = $this->skinArray[$diggthis_data['skin']];
		}else{
			$diggSkin = $this->skinArray['default'];
		}
		//Build the URL with extra options
		$diggURL = "http://digg.com/submit?";
		$diggURL .= "url=".urlencode(get_permalink());
		//Add title
		$diggURL .= "&title=".urlencode(get_the_title());
		//Related Posts
		$diggURL .= ( $diggthis_data['related'] == '1' ) ? '&related=no' : '';
		//Are we using custom CSS?
		$diggURL .= ( trim($this->diggthis_data['css']) != '' ) ? '&style=no':'';
		//Get media and topic type
		$diggTopic = ( in_array( $diggthis_data['media'], $this->mediaArray ) ) ? $diggthis_data['media'] : 'news';
		if( in_array($diggthis_data['topic'], $this->topicArray) ){
			$diggTopic .= ", ".$diggthis_data['topic'];
		}
		$diggTopic = ($diggTopic != 'news') ? 'rel="'.$diggTopic.'"':'';
		//Add body text
		$diggDescription = '<span style="display:none">'.apply_filters('the_excerpt_rss', get_the_excerpt()).'</span>';
		?>
		<div style="<?php echo $style ?>">
			<a class="DiggThisButton <?php echo $diggSkin; ?>" href="<?php echo $diggURL; ?>" <?php echo $diggTopic ?>><?php echo $diggDescription ?></a>		
		</div>		
		<?php
	}
}
//Include admin file if needed
if(is_admin()){
	include_once('digg-this-admin.php');
}

//Add translation
load_plugin_textdomain('diggthisbutton', "/wp-content/plugins/digg-this-button/langs/"); 

//Shortcut
function diggthisbutton( $atts=array() ){
	global $DiggThisButton;
	echo $DiggThisButton->shortcode($atts);	
}

// Start this plugin once all other plugins are fully loaded
add_action( 'init', create_function( '', 'global $DiggThisButton; $DiggThisButton = new DiggThisButton();' ), 10 );

?>